@@ -79,11 +79,17 @@ var cy = cytoscape({
         'opacity': 0.8,
         'text-opacity': 1,
         'line-color': '#909090',
+        'line-style': 'solid',
         'text-background-color' : '#ffffff',
         'text-background-shape' : 'roundrectangle',
         'text-background-opacity': 1,
         'text-background-padding' : 4,
         'min-zoomed-font-size': 10,
+        'line-dash-pattern': [100, 10],
+      })
+    .selector('edge[polytomy]')
+      .css({
+        'line-style': 'dashed',
       })
     .selector('edge[edge_name>1]')
       .css({
@@ -134,7 +140,7 @@ function addQtips() {
                     tooltip += '<br>{{age_label}}: ' + this.data('node_root_dates') + '<br>';
                 }
                 tooltip += '<br>{{tips}} inside: ' + this.data('node_in_tips');
-                tooltip += '<br>total {{tips}} in the subtree: ' + this.data('node_all_tips');
+                tooltip += '<br>total samples in the subtree (inc. trimmed): ' + this.data('node_all_tips');
                 tooltip += '<br>{{internal_nodes}} inside: ' + this.data('node_in_ns');
                 return tooltip;
             },
